<?php namespace EscapeWork\Manager\News\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\News\Repositories\NewsRepository;
use EscapeWork\Manager\News\Repositories\NewsCategoryRepository;
use EscapeWork\Manager\News\Models\News;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;

class NewsController extends ManagerController
{

    public function __construct(
        NewsRepository $news,
        NewsCategoryRepository $newsCategory)
    {
        parent::__construct();

        $this->news         = $news;
        $this->newsCategory = $newsCategory;

        # filters
        $this->validatePermissions('news');

        # view
        View::share('page', 'news');
    }

    public function index()
    {
        $view             = View::make(Config::get('manager-news::views.news.index'));
        $view->notices    = $this->news->filterAndPaginate(Input::all());
        $view->categories = $this->newsCategory->all();
        $view->params     = Input::all();

        return $view;
    }

    public function create()
    {
        $this->news->fill(Input::old());

        $view             = View::make(Config::get('manager-news::views.news.form'));
        $view->news       = $this->news;
        $view->categories = $this->newsCategory->all();
        $view->edit       = false;

        return $view;
    }

    public function store()
    {
        $this->news->fill(Input::all());

        if (! $this->news->validate()) {
            return Redirect::route('manager.news.create')
                        ->withInput()
                        ->withErrors($this->news->messages());
        }

        $this->news->save();

        return Redirect::route('manager.news.index')
                       ->with('message', 'A notícia <strong>' . $this->news->title . '</strong> foi inserida com sucesso!');
    }

    public function edit($id)
    {
        $this->news->findOrFail($id);

        $view               = View::make(Config::get('manager-news::views.news.form'));
        $view->news         = $this->news;
        $view->categories   = $this->newsCategory->all();
        $view->edit         = true;

        return $view;
    }

    public function update($id)
    {
        $this->news->findOrFail($id);
        $this->news->fill(Input::all());

        if (! $this->news->validate()) {
            return Redirect::route('manager.news.edit', array($this->news->id))
                    ->withInput()
                    ->withErrors($this->news->messages());
        }

        $this->news->save();

        return Redirect::route('manager.news.index')
                ->with('message', 'A notícia <strong>'.$this->news->title.'</strong> foi editada com sucesso!');
    }

    public function destroy($id)
    {
        $this->news = $this->news->findOrFail($id);
        $this->news->delete();

        return Redirect::route('manager.news.index')
                ->with('message', 'A notícia <strong>'.$this->news->title.'</strong> foi excluída com sucesso!');
    }

    public function updateActive($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Response::json(array(
                'error' => 'Noticia não encontrada'
            ));
        }

        $this->news->active = Input::get('active');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso'
        ));
    }

    public function updateFeatured($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Response::json(array(
                'error' => 'Noticia não encontrada'
            ));
        }

        $this->news->featured = Input::get('featured');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso',
            'news'    => $this->news->toArray(),
        ));
    }

    public function updateOrder($id)
    {
        $this->news        = $this->news->findOrFail($id);
        $this->news->order = Input::get('order');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso'
        ));
    }

    public function rss()
    {
        $view       = View::make(Config::get('manager-news::views.news.rss'));
        $view->news = $this->news->getLastNews(15);

        $response = Response::make($view->render());
        $response->header('Content-Type', 'text/xml; charset=utf-8');

        return $response;
    }
}
