@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a></li>
        <li><a href="{{ route('manager.news.index') }}">Notícias</a></li>
        <li class="active">{{ $edit ? 'Editar notícia' : 'Inserir notícia' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Notícias <small>{{ $edit ? 'Editar notícia' : 'Inserir notícia' }}</small></h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.news.index') }}" class="btn btn-default">Cancelar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    @include('manager::inc.messages')

    <form action="{{ ! $edit ? route('manager.news.store') : route('manager.news.update', $news->id) }}" method="post" id="form-news" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put">
        @endif

        <fieldset>
            @section('fields')
                @if ($categories->count() > 0)
                    <div class="form-group">
                        <label for="category" class="col-sm-2 control-label">Categoria</label>

                        <div class="col-sm-4">
                            {{ Form::select('news_category_id', $categories->combobox(['empty_option' => true]), $news->news_category_id, ['class' => 'form-control', 'id' => 'news_category_id'])}}
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif

                <div class="form-group">
                    <label for="title" class="col-sm-2 control-label">Título</label>

                    <div class="col-sm-8">
                        <input type="text" name="title" id="title" class="form-control" value="{{ $news->title }}" required autofocus>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                @if (! manager_field_hidden('subtitle', 'news'))
                    <div class="form-group">
                        <label for="subtitle" class="col-sm-2 control-label">Subtítulo</label>

                        <div class="col-sm-8">
                            <input type="text" name="subtitle" id="subtitle" class="form-control" value="{{ $news->subtitle }}">
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif

                <div class="form-group">
                    <label for="date" class="col-sm-2 control-label">Data</label>

                    <div class="col-sm-2">
                        <div class="input-group">
                            <input type="text" name="date" id="date" class="form-control" value="{{ $news->date ? $news->date->format('d/m/Y') : null }}" maxlength="255" required data-datepicker>
                            <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                        </div><!-- .input-append -->

                        <span class="help-block">dd/mm/aaaa</span>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="description" class="col-sm-2 control-label">Notícia</label>

                    <div class="col-sm-8">
                        <textarea  name="description" id="description" rows="20" data-editor>{{ $news->description }}</textarea>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                @if (! manager_field_hidden('source', 'news'))
                    <div class="form-group">
                        <label for="source" class="col-sm-2 control-label">Fonte</label>

                        <div class="col-sm-8">
                            <input type="text" name="source" id="source" class="form-control" value="{{ $news->source }}">
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif
            @show
        </fieldset>

        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="Aguarde...">Salvar</button>
                <a href="{{ route('manager.news.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-group -->
    </form>
@stop

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        $('#form-news').on('submit', function(e) {
            $(this).find('.js-btn-submit').button('loading');
        });
    })();
    </script>
@stop
