@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a></li>
        <li class="active">Notícias</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Notícias</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.news.create') }}" class="btn btn-primary">Inserir nova notícia</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page=header -->

    @include('manager::inc.messages')

    <form action="{{ route('manager.news.index') }}" class="well form-inline" method="get" id="form-search">
        <div class="form-group">
            <label>
                <input type="text" name="title" placeholder="Título..." value="{{ Input::get('title') }}" maxlength="100" class="form-control">
            </label>&nbsp;
        </div>

        @if ($categories->count() > 0)
            <div class="form-group">
                <label>
                    {{ Form::select('news_category_id', $categories->combobox(['empty_option' => true, 'empty_option_label' => 'Categoria']), Input::get('news_category_id'), ['class' => 'form-control'])}}
                </label> &nbsp;&nbsp;
            </div>
        @endif

        @if (! manager_field_hidden('featured', 'news'))
            <div class="checkbox">
                <label>
                    <input type="checkbox" name="featured" value="1" {{ Input::get('featured') == 1 ? 'checked="checked"' : null }} /> &nbsp;
                    Apenas destaques &nbsp;&nbsp;
                </label>
            </div>
        @endif

        <button type="submit" class="btn btn-primary">
            <span class="glyphicon glyphicon-search"></span> Buscar
        </button>

        <a class="btn" href="{{ route('manager.news.index') }}">
            Limpar filtros
        </a>
    </form>

    <table class="table table-bordered table-striped table-hover">
        <thead>
            <tr>
                <th><a href="{{ manager_order_by_link('manager.news.index', 'news.id', $params) }}" title="Ordenar pelo código">#</a></th>
                <th><a href="{{ manager_order_by_link('manager.news.index', 'news.title', $params) }}" title="Ordenar pelo título">Título</a></th>
                @if ($categories->count() > 0)
                    <th><a href="{{ manager_order_by_link('manager.news.index', 'news_categories.category', $params) }}" title="Ordenar pela categoria">Categoria</a></th>
                @endif
                <th><a href="{{ manager_order_by_link('manager.news.index', 'news.date', $params) }}" title="Ordenar pela data">Data</a></th>

                @if (! manager_field_hidden('featured', 'news'))
                    <th>Destaque</th>
                    <th>
                        <a href="{{ manager_order_by_link('manager.news.index', 'news.order', $params) }}" title="Ordenar pela ordem">Ordem</a>
                        <button type="button" class="btn btn-xs" data-toggle="popover" data-content="Digite nos campos abaixo a ordem em que os destaques serão exibidos." data-original-title="Ordenação dos destaques">
                            <span class="glyphicon glyphicon-question-sign"></span>
                        </button>
                    </th>
                @endif

                <th>Ativo</th>
                <th width="18%">Ações</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($notices as $news)
                <tr>
                    <td>{{ $news->id }}</td>
                    <td>{{ $news->title }}</td>
                    @if ($categories->count() > 0)
                        <td>{{ $news->category }}</td>
                    @endif
                    <td>{{ date('d/m/y', strtotime(str_replace('-', '/', $news->date))) }}</td>

                    @if (! manager_field_hidden('featured', 'news'))
                        <td><input type="checkbox" value="1" data-id="{{ $news->id }}" class="js-update-featured" {{ $news->featured ? 'checked="checked"' : null }} /></td>
                        <td><input type="number" class="update-order js-update-order" data-id="{{ $news->id }}" value="{{ $news->order }}" {{ $news->featured ?: 'disabled="disabled"' }} min="1" step="1" style="width: 35px;" /></td>
                    @endif

                    <td><input type="checkbox" value="1" data-id="{{ $news->id }}" class="js-update-active" {{ $news->active ? 'checked="checked"' : null }} /></td>
                    <td>
                        <div class="btn-group btn-group-sm">
                            <a href="{{ manager_media_route($news) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-camera"></span> fotos
                            </a>

                            <a href="{{ route('manager.news.edit', $news->id) }}" class="btn btn-default" title="Editar">
                                <span class="glyphicon glyphicon-pencil"></span> editar
                            </a>

                            <a href="{{ route('manager.news.destroy', $news->id) }}" class="btn btn-default" data-delete="true" title="Excluir">
                                <span class="glyphicon glyphicon-trash"></span> excluir
                            </a>
                        </div><!-- .btn-group -->
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table><!-- .table -->

    {{ $notices->appends(Input::except('page'))->links() }}
@stop

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        window.App  = window.App || {};
        App.Manager = App.Manager || {};

        App.Manager.News = {
            init: function() {
                this.listenEventsActive();
                this.listenEventsFeature();
                this.bindUIEvents();

                $('[data-toggle="popover"]').popover();
            },

            bindUIEvents: function() {
                var _this = this;

                $('.js-update-order').on('blur', function(e) {
                    _this.updateOrder($(this));
                });
            },

            listenEventsActive: function() {
                var _this = this;

                $('.js-update-active').on('change', function(e) {
                    _this.updateActive($(this));
                });
            },

            updateActive: function($news) {
                var _this  = this,
                    id     = $news.data('id'),
                    active = $news.prop('checked') ? 1 : 0;

                $news.prop('disabled', true)

                $.post("{{ route('manager.news.index') }}/"+id+"/active", {
                    _method: 'put',
                    active: active
                }, function(result) {
                    $news.prop('disabled', false)
                });
            },

            listenEventsFeature: function() {
                var _this = this;

                $('.js-update-featured').on('change', function(e) {
                    _this.updateFeatured($(this));
                });
            },

            updateFeatured: function($news) {
                    var _this  = this,
                    id     = $news.data('id'),
                    featured = $news.prop('checked') ? 1 : 0;

                $news.prop('disabled', true)

                $.post("{{ route('manager.news.index') }}/"+id+"/featured", {
                    _method: 'put',
                    featured: featured
                }, function(result) {
                    $news.prop('disabled', false);

                    if ($news.prop('checked') === true) {
                        $news.parent().next('td').find('.js-update-order').prop('disabled', false).val(result.news.order);
                    } else {
                        $news.parent().next('td').find('.js-update-order').val('').prop('disabled', true);
                    }
                });
            },

            updateOrder: function($order) {
                $order.prop('disabled', true);

                $.post("{{ route('manager.news.index') }}/"+$order.data('id')+"/order", {
                    _method: 'put',
                    order: $order.val()
                }, function(result) {
                    $order.prop('disabled', false);
                });
            }
        }

        App.Manager.News.init();
    })();
    </script>
@stop

